nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Galr

Struct Galr 

#[repr(transparent)]
pub struct Galr(pub u32);
Descriptor Group Lower Address Register

Tuple Fields

0: u32

Implementations

Source

impl Galr

pub const fn gaddr2(&self) -> u32

Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address

pub const fn set_gaddr2(&mut self, val: u32)

Contains the lower 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address