nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Gaur

Struct Gaur 

#[repr(transparent)]
pub struct Gaur(pub u32);
Descriptor Group Upper Address Register

Tuple Fields

0: u32

Implementations

Source

impl Gaur

pub const fn gaddr1(&self) -> u32

Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address

pub const fn set_gaddr1(&mut self, val: u32)

Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address