nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

IeeeTOctetsOk

Struct IeeeTOctetsOk 

#[repr(transparent)]
pub struct IeeeTOctetsOk(pub u32);
Octet Count for Frames Transmitted w/o Error Statistic Register

Tuple Fields

0: u32

Implementations

Source

impl IeeeTOctetsOk

pub const fn count(&self) -> u32

Octet count for frames transmitted without error Counts total octets (includes header and FCS fields).

pub const fn set_count(&mut self, val: u32)

Octet count for frames transmitted without error Counts total octets (includes header and FCS fields).