nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Paur

Struct Paur 

#[repr(transparent)]
pub struct Paur(pub u32);
Physical Address Upper Register

Tuple Fields

0: u32

Implementations

Source

impl Paur

pub const fn type_(&self) -> u16

Type Field In PAUSE Frames

pub const fn set_type_(&mut self, val: u16)

Type Field In PAUSE Frames

pub const fn paddr2(&self) -> u16

Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used for exact match, and the source address field in PAUSE frames

pub const fn set_paddr2(&mut self, val: u16)

Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used for exact match, and the source address field in PAUSE frames