nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Rdsr

Struct Rdsr 

#[repr(transparent)]
pub struct Rdsr(pub u32);
Receive Descriptor Ring 0 Start Register

Tuple Fields

0: u32

Implementations

Source

impl Rdsr

pub const fn r_des_start(&self) -> u32

Pointer to the beginning of the receive buffer descriptor queue.

pub const fn set_r_des_start(&mut self, val: u32)

Pointer to the beginning of the receive buffer descriptor queue.