#[repr(transparent)]pub struct Gaur(pub u32);Expand description
Descriptor Group Upper Address Register
Tuple Fields
0: u32Implementations
Sourceimpl Gaur
impl Gaur
Sourcepub const fn gaddr1(&self) -> u32
pub const fn gaddr1(&self) -> u32
Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address
Sourcepub const fn set_gaddr1(&mut self, val: u32)
pub const fn set_gaddr1(&mut self, val: u32)
Contains the upper 32 bits of the 64-bit hash table used in the address recognition process for receive frames with a multicast address