#[repr(transparent)]pub struct Paur(pub u32);Expand description
Physical Address Upper Register
Tuple Fields
0: u32Implementations
Sourceimpl Paur
impl Paur
Sourcepub const fn paddr2(&self) -> u16
pub const fn paddr2(&self) -> u16
Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used for exact match, and the source address field in PAUSE frames
Sourcepub const fn set_paddr2(&mut self, val: u16)
pub const fn set_paddr2(&mut self, val: u16)
Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used for exact match, and the source address field in PAUSE frames